==> couchdb-auth-proxy-1.0.0.tgz: package/index.js <==
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var crypto = _interopDefault(require('crypto'));
var url = require('url');
var httpProxy = _interopDefault(require('http-proxy'));
var transformerProxy = _interopDefault(require('transformer-proxy'));

var name = "couchdb-auth-proxy";
var version = "1.0.0";

var asyncToGenerator = function (fn) {
  return function () {
    var gen = fn.apply(this, arguments);
    return new Promise(function (resolve, reject) {
      function step(key, arg) {
        try {
          var info = gen[key](arg);
          var value = info.value;
        } catch (error) {
          reject(error);
          return;
        }

        if (info.done) {
          resolve(value);
        } else {
          return Promise.resolve(value).then(function (value) {
            return step("next", value);
          }, function (err) {
            return step("throw", err);
          });
        }
      }

      return step("next");
    });
  };
};

const injectProxyInfo = transformerProxy(function (data) {
	const body = JSON.parse(data);
	body.proxy = { name, version };
	return JSON.stringify(body);
});

function index (fn) {
	let opts = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

	if (typeof fn === "object") {
		;

		var _ref = [fn, opts];
		opts = _ref[0];
		fn = _ref[1];
	}var _opts = opts;
	let via = _opts.via;
	let secret = _opts.secret;
	var _opts$target = _opts.target;
	let target = _opts$target === undefined ? "http://localhost:5984" : _opts$target;
	var _opts$headerFields = _opts.headerFields;
	let headerFields = _opts$headerFields === undefined ? {} : _opts$headerFields;


	headerFields = Object.assign({
		username: "X-Auth-CouchDB-UserName",
		roles: "X-Auth-CouchDB-Roles",
		token: "X-Auth-CouchDB-Token"
	}, headerFields);

	const proxy = httpProxy.createProxyServer({});

	return (() => {
		var _ref2 = asyncToGenerator(function* (req, res, next) {
			try {
				// hijack the root response and inject proxy information
				if (url.parse(req.url).pathname === "/") {
					yield confusedAsync(injectProxyInfo, null, [req, res]);
				}

				// inject couchdb proxy headers into request
				const ctx = yield confusedAsync(fn, null, [req, res]);
				if (ctx != null) {
					const name = typeof ctx.name === "string" ? ctx.name : "";
					req.headers[headerFields.username] = name;
					req.headers[headerFields.roles] = Array.isArray(ctx.roles) ? ctx.roles.join(",") : "";
					if (secret) req.headers[headerFields.token] = signRequest(name, secret);
				}

				// attach Via header on response
				// do this last in case there was an error
				if (via) {
					const writeHead = res.writeHead;
					res.writeHead = function (code, headers) {
						const existing = res.getHeader("Via");
						const viaheader = `${ existing ? existing + ", " : "" }${ req.httpVersion } ${ via } (${ name }/${ version })`;
						res.setHeader("Via", viaheader);
						if (headers) headers["Via"] = viaheader;

						return writeHead.apply(res, arguments);
					};
				}

				proxy.web(req, res, { target });
			} catch (e) {
				next(e);
			}
		});

		return function (_x2, _x3, _x4) {
			return _ref2.apply(this, arguments);
		};
	})();
}

// couchdb proxy signed token
function signRequest(user, secret) {
	return crypto.createHmac("sha1", secret).update(user).digest("hex");
}

// for methods that we don't know if they are callback or promise async
function confusedAsync(fn, ctx) {
	let args = arguments.length <= 2 || arguments[2] === undefined ? [] : arguments[2];

	if (fn.length > args.length) {
		return new Promise(function (resolve, reject) {
			fn.apply(ctx, args.concat(function (err, r) {
				if (err) reject(err);else resolve(r);
			}));
		});
	} else {
		return Promise.resolve(fn.apply(ctx, args));
	}
}

module.exports = index;

==> couchdb-auth-proxy-1.1.0.tgz: package/index.js <==
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var crypto = require('crypto');
var url = require('url');
var httpProxy = _interopDefault(require('http-proxy'));
var transformerProxy = _interopDefault(require('transformer-proxy'));

var name = "couchdb-auth-proxy";
var version = "1.1.0";

var asyncToGenerator = function (fn) {
  return function () {
    var gen = fn.apply(this, arguments);
    return new Promise(function (resolve, reject) {
      function step(key, arg) {
        try {
          var info = gen[key](arg);
          var value = info.value;
        } catch (error) {
          reject(error);
          return;
        }

        if (info.done) {
          resolve(value);
        } else {
          return Promise.resolve(value).then(function (value) {
            return step("next", value);
          }, function (err) {
            return step("throw", err);
          });
        }
      }

      return step("next");
    });
  };
};

function index (fn) {
	let opts = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

	if (typeof fn === "object") {
		;

		var _ref = [fn, opts];
		opts = _ref[0];
		fn = _ref[1];
	}var _opts = opts;
	let via = _opts.via;
	let secret = _opts.secret;
	var _opts$target = _opts.target;
	let target = _opts$target === undefined ? "http://localhost:5984" : _opts$target;
	var _opts$headerFields = _opts.headerFields;
	let headerFields = _opts$headerFields === undefined ? {} : _opts$headerFields;
	var _opts$info = _opts.info;
	let info = _opts$info === undefined ? { name, version } : _opts$info;


	headerFields = Object.assign({
		username: "X-Auth-CouchDB-UserName",
		roles: "X-Auth-CouchDB-Roles",
		token: "X-Auth-CouchDB-Token"
	}, headerFields);

	const injectProxyInfo = info ? transformerProxy(function (data) {
		const body = JSON.parse(data);
		body.proxy = info;
		return JSON.stringify(body);
	}) : null;

	const proxy = httpProxy.createProxyServer({});

	return (() => {
		var _ref2 = asyncToGenerator(function* (req, res, next) {
			try {
				// hijack the root response and inject proxy information
				if (injectProxyInfo && url.parse(req.url).pathname === "/") {
					yield confusedAsync(injectProxyInfo, null, [req, res]);
				}

				// inject couchdb proxy headers into request
				const ctx = yield confusedAsync(fn, null, [req, res]);
				if (ctx != null) {
					const name = typeof ctx.name === "string" ? ctx.name : "";
					req.headers[headerFields.username] = name;
					req.headers[headerFields.roles] = Array.isArray(ctx.roles) ? ctx.roles.join(",") : "";
					if (secret) req.headers[headerFields.token] = signRequest(name, secret);
				}

				// attach Via header on response
				// do this last in case there was an error
				if (via) {
					const writeHead = res.writeHead;
					res.writeHead = function (code, headers) {
						const existing = res.getHeader("Via");
						const viaheader = `${ existing ? existing + ", " : "" }${ req.httpVersion } ${ via } (${ name }/${ version })`;
						res.setHeader("Via", viaheader);
						if (headers) headers["Via"] = viaheader;

						return writeHead.apply(res, arguments);
					};
				}

				proxy.web(req, res, { target });
			} catch (e) {
				if (next) next(e);else throw e;
			}
		});

		return function (_x2, _x3, _x4) {
			return _ref2.apply(this, arguments);
		};
	})();
}

// couchdb proxy signed token
function signRequest(user, secret) {
	return crypto.createHmac("sha1", secret).update(user).digest("hex");
}

// for methods that we don't know if they are callback or promise async
function confusedAsync(fn, ctx) {
	let args = arguments.length <= 2 || arguments[2] === undefined ? [] : arguments[2];

	if (fn.length > args.length) {
		return new Promise(function (resolve, reject) {
			fn.apply(ctx, args.concat(function (err, r) {
				if (err) reject(err);else resolve(r);
			}));
		});
	} else {
		return Promise.resolve(fn.apply(ctx, args));
	}
}

module.exports = index;
